@@ -3,11 +3,12 @@ import os   # noqa E402
 import sys
 import datetime
 
-os.environ['PANDA_URL'] = 'http://ai-idds-01.cern.ch:25080/server/panda'
-os.environ['PANDA_URL_SSL'] = 'https://ai-idds-01.cern.ch:25443/server/panda'
+os.environ['PANDA_URL'] = 'http://pandaserver-doma.cern.ch:25080/server/panda'
+os.environ['PANDA_URL_SSL'] = 'https://pandaserver-doma.cern.ch:25443/server/panda'
 
 from pandatools import Client  # noqa E402
 
+"""
 jobids = [1408118]
 jobs_list_status = Client.getJobStatus(jobids, verbose=0)
 print(jobs_list_status)
@@ -35,7 +36,6 @@ print(ret)
 ret = Client.getTaskStatus(jediTaskID, verbose=False)
 print(ret)
 
-"""
 sys.exit(0)
 
 jediTaskID = 998
@@ -70,7 +70,7 @@ task_ids = []
 task_ids = []
 for task_id in task_ids:
     print("Killing %s" % task_id)
-    Client.killTask(task_id)
+    # Client.killTask(task_id)
 
 """
 jobids = []
@@ -103,11 +103,10 @@ newOpts = {}
 # site = newOpts.get('site', None)
 # excludedSite = newOpts.get('excludedSite', None)
 # for JEDI
-"""
-taskID=26034796
-status, out = Client.retryTask(taskID, verbose=True, properErrorCode=True, newParams=newOpts)
-print(status)
-print(out)
-"""
+taskIDs = [7056, 7057]
+for taskID in taskIDs:
+    status, out = Client.retryTask(taskID, verbose=True, properErrorCode=True, newParams=newOpts)
+    print(status)
+    print(out)
 
 sys.exit(0)
